<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="134"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="135"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="137"/>
        <source>Lightweight file manager</source>
        <translation>Gestore file leggero</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="138"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="143"/>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>PCMan Gestore file

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

Questo programma è software libero; puoi redistribuirlo e/o
modificarlo nei termini della GNU General Public License
come pubblicata dalla Free Software Foundation; nella versione 2
della licenza, o (a tua scelta) qualsiasi versione successiva.

Questo programma è distribuito nella speranza che possa essere utile,
ma SENZA ALCUNA GARANZIA; senza nemmeno la garanzia implicita di
COMMERCIABILITÀ o IDONEITÀ PER FINI PARTICOLARI. Vedi la
GNU General Public License per ulteriori dettagli.

Dovresti aver ricevuto una copia della GNU General Public License
insieme a questo programma; In caso contrario, scrivi a Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://pcmanfm.sourceforge.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://pcmanfm.sourceforge.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://pcmanfm.sourceforge.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://pcmanfm.sourceforge.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="139"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programmazione:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="142"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="160"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="110"/>
        <source>Removable medium is inserted</source>
        <translation>Supporto rimovibile inserito</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="112"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Supporto rimovibile inserito&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="113"/>
        <source>Type of medium:</source>
        <translation>Tipo di supporto:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="114"/>
        <source>Detecting...</source>
        <translation>Rilevamento...</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="115"/>
        <source>Please select the action you want to perform:</source>
        <translation>Seleziona l&apos;azione da eseguire:</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="75"/>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="76"/>
        <source>Desktop</source>
        <translation>Scrivania</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="77"/>
        <source>Desktop folder:</source>
        <translation>Cartella della scrivania:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="79"/>
        <source>Image file</source>
        <translation>File immagine</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="84"/>
        <source>Folder path</source>
        <translation>Percorso della cartella</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="85"/>
        <source>&amp;Browse</source>
        <translation>&amp;Sfoglia</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="254"/>
        <source>Desktop Preferences</source>
        <translation>Preferenze della scrivania</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="255"/>
        <source>Background</source>
        <translation>Sfondo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="256"/>
        <source>Wallpaper mode:</source>
        <translation>Modalità sfondo:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="257"/>
        <source>Wallpaper image file:</source>
        <translation>File immagine di sfondo:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="259"/>
        <source>Select background color:</source>
        <translation>Seleziona il colore di sfondo:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="261"/>
        <source>Image file</source>
        <translation>File immagine</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="266"/>
        <source>Image file path</source>
        <translation>Percorso al file immagine</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="267"/>
        <source>&amp;Browse</source>
        <translation>&amp;Sfoglia</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="268"/>
        <source>Label Text</source>
        <translation>Testo etichette</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="271"/>
        <source>Select  text color:</source>
        <translation>Seleziona il colore del testo:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="272"/>
        <source>Select shadow color:</source>
        <translation>Seleziona il colore delle ombre:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="273"/>
        <source>Select font:</source>
        <translation>Seleziona il carattere:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="275"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="276"/>
        <source>Window Manager</source>
        <translation>Gestore delle finestre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="277"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>Mostra i menu forniti dal gestore delle finestre quando fai clic sul desktop</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Scrivania</translation>
    </message>
    <message>
        <source>Desktop folder:</source>
        <translation>Cartella della scrivania:</translation>
    </message>
    <message>
        <source>Folder path</source>
        <translation>Percorso della cartella</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="278"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="557"/>
        <source>File Manager</source>
        <translation>Gestore file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="560"/>
        <source>Go Up</source>
        <translation>Vai su</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="562"/>
        <source>Alt+Up</source>
        <translation>Alt+Su</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Cartella home</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="564"/>
        <source>Alt+Home</source>
        <translation>Alt+Inizio</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="583"/>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="566"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="563"/>
        <source>&amp;Home</source>
        <translation>&amp;Home</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="565"/>
        <source>&amp;Reload</source>
        <translation>&amp;Ricarica</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="567"/>
        <source>Go</source>
        <translation>Vai</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="568"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="569"/>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="572"/>
        <source>New Window</source>
        <translation>Nuova finestra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="574"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="575"/>
        <source>Show &amp;Hidden</source>
        <translation>Mostra i file &amp;nascosti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="576"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="577"/>
        <source>&amp;Computer</source>
        <translation>&amp;Computer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="578"/>
        <source>&amp;Trash</source>
        <translation>Ces&amp;tino</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="579"/>
        <source>&amp;Network</source>
        <translation>&amp;Rete</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="580"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Scrivania</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="581"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Aggiungi ai segnalibri</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="582"/>
        <source>&amp;Applications</source>
        <translation>&amp;Applicazioni</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="589"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="590"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="591"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="592"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="593"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="594"/>
        <source>Select &amp;All</source>
        <translation>Seleziona t&amp;utto</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="596"/>
        <source>Pr&amp;eferences</source>
        <translation>Pr&amp;eferenze</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="597"/>
        <source>&amp;Ascending</source>
        <translation>&amp;Crescente</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="598"/>
        <source>&amp;Descending</source>
        <translation>&amp;Decrescente</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="599"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Per nome file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="600"/>
        <source>By &amp;Modification Time</source>
        <translation>Per data di &amp;modifica</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="601"/>
        <source>By File &amp;Type</source>
        <translation>Per &amp;tipo di file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="602"/>
        <source>By &amp;Owner</source>
        <translation>Per pr&amp;oprietario</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="603"/>
        <source>&amp;Folder First</source>
        <translation>Prima le ca&amp;rtelle</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Inverti selezione</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="620"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="622"/>
        <source>&amp;Rename</source>
        <translation>&amp;Rinomina</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="595"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="558"/>
        <source>Go &amp;Up</source>
        <translation>Vai &amp;su</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="570"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nuova finestra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="584"/>
        <source>&amp;Icon View</source>
        <translation>Vista &amp;icone</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="585"/>
        <source>&amp;Compact View</source>
        <translation>Vista &amp;compatta</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="586"/>
        <source>&amp;Detailed List</source>
        <translation>Elenco &amp;dettagliato</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="587"/>
        <source>&amp;Thumbnail View</source>
        <translation>Vista minia&amp;ture</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="588"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Taglia</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation>Crescente</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>Decrescente</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation>Per nome file</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation>Per data modifica</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation>Per tipo file</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation>Per proprietario</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation>Prima le cartelle</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="604"/>
        <source>New &amp;Tab</source>
        <translation>Nuova sc&amp;heda</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="606"/>
        <source>New Tab</source>
        <translation>Nuova scheda</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="608"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="609"/>
        <source>Go &amp;Back</source>
        <translation>Vai in&amp;dietro</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="611"/>
        <source>Go Back</source>
        <translation>Va indietro</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="613"/>
        <source>Alt+Left</source>
        <translation>Alt+Sinistra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="614"/>
        <source>Go &amp;Forward</source>
        <translation>Vai &amp;avanti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="616"/>
        <source>Go Forward</source>
        <translation>Va avanti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="618"/>
        <source>Alt+Right</source>
        <translation>Alt+Destra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="621"/>
        <source>Del</source>
        <translation>Canc</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="623"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="624"/>
        <source>C&amp;lose Tab</source>
        <translation>C&amp;hiudi scheda</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="626"/>
        <source>File &amp;Properties</source>
        <translation>&amp;Proprietà file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="628"/>
        <source>&amp;Folder Properties</source>
        <translation>Proprietà &amp;cartella</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="629"/>
        <source>&amp;Case Sensitive</source>
        <translation>Distingui le maius&amp;cole</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="630"/>
        <source>By File &amp;Size</source>
        <translation>Per dimen&amp;sione del file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="631"/>
        <source>&amp;Close Window</source>
        <translation>&amp;Chiudi finestra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="637"/>
        <source>&amp;Folder</source>
        <translation>&amp;Cartella</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="638"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="639"/>
        <source>&amp;Blank File</source>
        <translation>File &amp;vuoto</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="640"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="641"/>
        <source>&amp;Find Files</source>
        <translation>Trova &amp;file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="642"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="643"/>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="644"/>
        <source>Filter by string...</source>
        <translation>Filtra per stringa...</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="646"/>
        <source>C&amp;reate New</source>
        <translation>C&amp;rea nuovo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="649"/>
        <source>&amp;Sorting</source>
        <translation>&amp;Ordinamento</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="654"/>
        <source>Main Toolbar</source>
        <translation>Barra degli strumenti principale</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="625"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="627"/>
        <source>Alt+Return</source>
        <translation>Alt+Invio</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Distingui le maiuscole</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation>Per dimensione del file</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Chiudi finestra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="632"/>
        <source>Edit Bookmarks</source>
        <translation>Modifica segnalibri</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="633"/>
        <source>Open &amp;Terminal</source>
        <translation>Apri &amp;terminale</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="634"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="635"/>
        <source>Open as &amp;Root</source>
        <translation>Apri come &amp;root</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="636"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;Modifica segnalibri</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="645"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="647"/>
        <source>&amp;Help</source>
        <translation>A&amp;iuto</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="648"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="650"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="651"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Segnalibri</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="652"/>
        <source>&amp;Go</source>
        <translation>&amp;Vai</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="653"/>
        <source>&amp;Tool</source>
        <translation>S&amp;trumenti</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>Name of configuration profile</source>
        <translation>Nome del profilo di configurazione</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>PROFILE</source>
        <translation>PROFILO</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="165"/>
        <source>Run PCManFM as a daemon</source>
        <translation>Esegui PCManFM come demone</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="168"/>
        <source>Quit PCManFM</source>
        <translation>Esci da PCManFM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="171"/>
        <source>Launch desktop manager</source>
        <translation>Lancia il gestore della scrivania</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="174"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Spegni il gestore della scrivania se è in esecuzione</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Apri le preferenze della scrivania alla pagina con il nome specificato</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <location filename="../application.cpp" line="193"/>
        <source>NAME</source>
        <translation>NOME</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Imposta lo sfondo della scrivania con l&apos;immagine dal FILE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>FILE</source>
        <translation>FILE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation>Imposta la modalità dello sfondo della scrivania. MODO=(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>MODE</source>
        <translation>MODO</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translatorcomment>where is that?</translatorcomment>
        <translation>Apri le preferenze alla pagina con il nome specificato</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="180"/>
        <source>Open new window</source>
        <translation>Apri una nuova finestra</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="183"/>
        <source>Open Find Files utility</source>
        <translation>Apri l&apos;utilità di ricerca file</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2, ...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Files or directories to open</source>
        <translation>File o cartelle da aprire</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="500"/>
        <location filename="../application.cpp" line="507"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="507"/>
        <source>Terminal emulator is not set.</source>
        <translation>L&apos;emulatore di terminale non è impostato.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="43"/>
        <source>Open in file manager</source>
        <translation>Apri nel gestore file</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="133"/>
        <source>Removable Disk</source>
        <translation>Disco rimovibile</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="50"/>
        <source>Fill with background color only</source>
        <translation>Riempi solo con il colore di sfondo</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="51"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Allarga per riempire tutto lo schermo</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Stretch to fit the screen</source>
        <translation>Restringi per adattare allo schermo</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Center on the screen</source>
        <translation>Centra nello schermo</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Ripete l&apos;immagine per riempire tutto lo schermo</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="157"/>
        <source>Image Files</source>
        <translation>File immagine</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="366"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>Blo&amp;cca alla posizione attuale</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="388"/>
        <source>Desktop Preferences</source>
        <translation>Preferenze della scrivania</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Cancella il testo (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>Version: %1</source>
        <translation>Versione:%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Move to Trash</source>
        <translation>Cestin&amp;a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Switch user command is not set.</source>
        <translation>Il comando per cambiare utente non è impostato.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="190"/>
        <source>Icon View</source>
        <translation>Vista icone</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="191"/>
        <source>Compact Icon View</source>
        <translation>Vista icone compatta</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="192"/>
        <source>Thumbnail View</source>
        <translation>Vista miniature</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="193"/>
        <source>Detailed List View</source>
        <translation>Vista elenco dettagliato</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="248"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="261"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Spazio libero: %1 (totale: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="276"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n elemento</numerusform>
            <numerusform>%n elementi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="278"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n nascosto)</numerusform>
            <numerusform> (%n nascosti)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="426"/>
        <source>%1 item(s) selected</source>
        <translation>%1 elementi selezionati</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="103"/>
        <source>Open in New T&amp;ab</source>
        <translation>Apri in una nuova sc&amp;heda</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="107"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Apri una nuova &amp;finestra</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>Apri nel termina&amp;le</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="706"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="715"/>
        <source>User Interface</source>
        <translation>Interfaccia utente</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="711"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="717"/>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="779"/>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="719"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="721"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="742"/>
        <source>Icons</source>
        <translation>Icone</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="744"/>
        <source>Size of big icons:</source>
        <translation>Dimensione delle icone grandi:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="745"/>
        <source>Size of small icons:</source>
        <translation>Dimensione delle icone piccole:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="746"/>
        <source>Size of thumbnails:</source>
        <translation>Dimensione delle miniature:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="747"/>
        <source>Size of side pane icons:</source>
        <translation>Dimensione delle icone del riquadro laterale:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="743"/>
        <source>Icon theme:</source>
        <translation>Tema delle icone:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="753"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="757"/>
        <source>Default width of new windows:</source>
        <translation>Larghezza predefinita delle nuove finestre:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="758"/>
        <source>Default height of new windows:</source>
        <translation>Altezza predefinita delle nuove finestre:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="754"/>
        <source>Always show the tab bar</source>
        <translation>Mostra sempre la barra delle schede</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="755"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Mostra pulsanti di chiusura sulle schede	</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="756"/>
        <source>Remember the size of the last closed window</source>
        <translation>Ricorda la dimensione della ultima finestra chiusa</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="724"/>
        <source>Browsing</source>
        <translation>Navigazione</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="725"/>
        <source>Open files with single click</source>
        <translation>Apri file con un clic singolo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="726"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Ritardo per la selezione automatica in modalità con clic singolo (0 per disabilitare)</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="727"/>
        <source>Default view mode:</source>
        <translation>Modalità vista predefinita:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="728"/>
        <source> sec</source>
        <translation>secondi</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="736"/>
        <source>File Operations</source>
        <translation>Operazioni sui file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="737"/>
        <source>Confirm before deleting files</source>
        <translation>Conferma prima di rimuovere i file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="738"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Sposta nel «Cestino» i file rimossi invece di eliminarli dal disco.</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="783"/>
        <source>Show thumbnails of files</source>
        <translation>Mostra miniature dei file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="782"/>
        <source>Only show thumbnails for local files</source>
        <translation>Mostra miniature solo per i file locali</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="713"/>
        <source>Display</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="729"/>
        <source>Bookmarks:</source>
        <translation>Segnalibri:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="732"/>
        <source>Open in current tab</source>
        <translation>Apri nella scheda attuale</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="733"/>
        <source>Open in new tab</source>
        <translation>Apri in una nuova scheda</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="734"/>
        <source>Open in new window</source>
        <translation>Apri una nuova finestra</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="739"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>Cancella i file sui supporti rimovibile invece di cestinarli</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="740"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Conferma prima di cestinare i file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="741"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>Non chiedere opzioni all&apos;avvio dei file eseguibili</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="748"/>
        <source>User interface</source>
        <translation>Interfaccia utente</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="750"/>
        <source>Treat backup files as hidden</source>
        <translation>Tratta i file di backup come nascosti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="751"/>
        <source>Always show full file names</source>
        <translation>Mostra sempre il nome completo dei file</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="752"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Mostra le icone dei file nascosti come ombreggiate</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="759"/>
        <source>Show in places</source>
        <translation>Mostra in Risorse</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="764"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="766"/>
        <source>Desktop</source>
        <translation>Scrivania</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="768"/>
        <source>Trash can</source>
        <translation>Cestino</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="770"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="772"/>
        <source>Applications</source>
        <translation>Applicazioni</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="774"/>
        <source>Devices</source>
        <translation>Dispositivi</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="776"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="780"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>Non generare miniature per file immagine più grandi di:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="781"/>
        <source> KB</source>
        <translation> KB</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="784"/>
        <source>Auto Mount</source>
        <translation>Montaggio automatico</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="785"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Monta automaticamente i volumi disponibili all&apos;avvio del programma</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="786"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Monta automaticamente i volumi rimovibli quando vengono inseriti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="787"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Mostra opzioni disponibili per i volumi rimovibli quando vengono inseriti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="788"/>
        <source>When removable medium unmounted:</source>
        <translation>Quando viene smontato un volume rimovibile:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="789"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>Chiudi &amp;scheda con il contenuto</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="790"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>Cambia in cartella &amp;home</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="793"/>
        <source>Switch &amp;user command:</source>
        <translation>Comando per &amp;cambiare utente:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="796"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>Gestore &amp;archivi da usare:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="797"/>
        <source>Templates</source>
        <translation>Modelli</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="798"/>
        <source>Show only user defined templates in menu</source>
        <translation>Mostra solo i modelli definiti dall&apos;utente nel menu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="799"/>
        <source>Show only one template for each MIME type</source>
        <translation>Mostra solo un modello per ogni tipo MIME</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="800"/>
        <source>Run default application after creation from template</source>
        <translation>Esegui l&apos;applicazione predefinita dopo la creazione da modello</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="791"/>
        <source>Programs</source>
        <translation>Programmi</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="792"/>
        <source>Terminal emulator:</source>
        <translation>Emulatore di terminale:</translation>
    </message>
    <message>
        <source>Switch user command:</source>
        <translation>Comando per cambiare utente:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="794"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>Esempi: &quot;xterm -e %s&quot; per il terminale o &quot;gksu %s&quot; per cambiare utente.
%s = la riga di comando da eseguire con il terminal o con su.</translation>
    </message>
    <message>
        <source>Archiver integration:</source>
        <translation>Integrazione con gli archivi:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="749"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Usa i prefissi decimali del SI invece di quelli binari dello IEC</translation>
    </message>
</context>
</TS>
